@@ -7,6 +7,7 @@
 #' @import mlr3tuning
 #' @import bbotk
 #' @importFrom R6 R6Class
+#' @importFrom utils head
 "_PACKAGE"
 
 register_bbotk = function() {
@@ -36,3 +37,5 @@ register_mlr3tuning = function() {
   walk(names(optimizers), function(id) bbotk::mlr_optimizers$remove(id))
   walk(names(tuners), function(id) mlr3tuning::mlr_tuners$remove(id))
 }
+
+leanify_package()
